@@ -2,13 +2,12 @@ import threading
 from time import time
 from typing import Callable
 
+from api_analytics.core import log_request
 from flask import Flask, Request, Response
 from flask_http_middleware import BaseHTTPMiddleware, MiddlewareManager
 
-from api_analytics.core import log_request
 
-
-def add_middleware(app: Flask, api_key: str) -> None:
+def add_middleware(app: Flask, api_key: str):
     app.wsgi_app = MiddlewareManager(app)
     app.wsgi_app.add_middleware(Analytics, api_key=api_key)
 
@@ -25,6 +24,7 @@ class Analytics(BaseHTTPMiddleware):
         data = {
             'api_key': self.api_key,
             'hostname': request.host,
+            'ip_address': request.remote_addr,
             'path': request.path,
             'user_agent': request.headers['user-agent'],
             'method': request.method,
@@ -32,5 +32,6 @@ class Analytics(BaseHTTPMiddleware):
             'framework': 'Flask',
             'response_time': int((time() - start) * 1000),
         }
+        
         threading.Thread(target=log_request, args=(data,)).start()
         return response
